
float x0;
float y0;
float hx;
float hy;
float vx;
float vy;

// Texture to be drawn
Texture g_Tex;
sampler2D s = sampler_state {
	Texture = <g_Tex>;
	MinFilter = LINEAR;
	MagFilter = LINEAR;
	MipFilter = NONE;
	AddressU = CLAMP;
	AddressV = CLAMP;
};

// Rock/Lava Color Gradient
Texture grad_Map;
sampler2D Gradient = sampler_state {
	Texture = <grad_Map>;
	MinFilter = LINEAR;
	MagFilter = LINEAR;
	MipFilter = NONE;
	AddressU = CLAMP;
	AddressV = CLAMP;
};

// Rock/Lava Pattern
Texture pat_Map;
sampler2D Pattern = sampler_state {
	Texture = <pat_Map>;
	MinFilter = LINEAR;
	MagFilter = LINEAR;
	MipFilter = NONE;
	AddressU = WRAP;
	AddressV = WRAP;
};

// Wood Texture
Texture wood_Map;
sampler2D Wood = sampler_state {
	Texture = <wood_Map>;
	MinFilter = LINEAR;
	MagFilter = LINEAR;
	MipFilter = NONE;
	AddressU = WRAP;
	AddressV = WRAP;
};

// Coal Texture
Texture coal_Map;
sampler2D Coal = sampler_state {
	Texture = <coal_Map>;
	MinFilter = LINEAR;
	MagFilter = LINEAR;
	MipFilter = NONE;
	AddressU = WRAP;
	AddressV = WRAP;
};


float4 draw ( float2 texCoords : TEXCOORD0 ) : COLOR
{
    float4 c = tex2D(s, texCoords);
    
    float3 newc = float3(0,0,0);
    
    // Material
    float2 coord = float2(x0 + hx*texCoords.x + vx*texCoords.y, y0 + hy*texCoords.x + vy*texCoords.y);
    if(c.a > 0.0) {
        if(c.b <= c.r) {
            // Rock/Lava
            float heat = c.r - c.g;
            float spec = tex2D(Pattern, coord).r;
            newc = tex2D(Gradient, float2(spec, heat));
        } else {
            // Wood
            newc = tex2D(Wood, coord);
            if(c.g > 0.0) {
                float coal = tex2D(Coal, coord).r;
                if(c.g > coal) {
                    float black = 8.0*(c.g-coal);
                    if(black >= 0.9) 
                        black = 0.9;
                    newc = black*float4(0,0,0,1) + (1-black)*newc;
                }
            }
        }
    }
    
    return float4(newc.r, newc.g, newc.b, c.a);
}







technique Draw
{
	pass p0
	{
		Sampler[0] = <s>;
		Sampler[1] = <Gradient>;
        Sampler[2] = <Pattern>;
        Sampler[3] = <Wood>;
		PixelShader = compile ps_2_0 draw();
	}
}
